(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs')) :
    typeof define === 'function' && define.amd ? define('lib', ['exports', '@angular/core', 'rxjs'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.lib = {}, global.ng.core, global.rxjs));
}(this, (function (exports, i0, rxjs) { 'use strict';

    var NgxSimpleScrollService = /** @class */ (function () {
        function NgxSimpleScrollService() {
            this.config = {
                scrollToFocus: true,
                scrollToParent: false,
                scrollToAnimatedObject: false,
            };
            this.focusParams = { preventScroll: true };
            this.scrollParams = { block: 'center', behavior: 'smooth' };
            this.animationInterval = 50;
        }
        NgxSimpleScrollService.prototype.scrollTo = function (config) {
            var mergedConfig = Object.assign(Object.assign({}, this.config), config);
            var targetSelector = mergedConfig.targetSelector;
            var target = document.querySelector(targetSelector);
            if (!target) {
                return;
            }
            if (mergedConfig.scrollToFocus) {
                this.focus(target, mergedConfig);
            }
            this.scroll(target, mergedConfig);
        };
        NgxSimpleScrollService.prototype.focus = function (target, config) {
            var isInput = target instanceof HTMLInputElement;
            var isTextarea = target instanceof HTMLTextAreaElement;
            if (isInput || isTextarea) {
                target.focus(this.focusParams);
                return;
            }
            if (!config.scrollToParent) {
                return;
            }
            var parent = this.getParent(target, config.parentSelector);
            if (!parent) {
                return;
            }
            var inputElement = parent.querySelector('input, textarea');
            if (!inputElement) {
                return;
            }
            inputElement.focus(this.focusParams);
        };
        NgxSimpleScrollService.prototype.scroll = function (target, config) {
            var _this = this;
            var el = config.scrollToParent
                ? this.getParent(target, config.parentSelector) || target
                : target;
            el.scrollIntoView(this.scrollParams);
            if (!config.scrollToAnimatedObject) {
                return;
            }
            this.initAnimationDoneSub(el)
                .subscribe(function () { return el.scrollIntoView(_this.scrollParams); });
        };
        NgxSimpleScrollService.prototype.initAnimationDoneSub = function (el) {
            var _this = this;
            var subj = new rxjs.Subject();
            var position = this.getElemPos(el);
            var interval = setInterval(function () {
                var newPos = _this.getElemPos(el);
                if (position !== newPos) {
                    position = newPos;
                    return;
                }
                clearInterval(interval);
                subj.next();
                subj.complete();
            }, this.animationInterval);
            return subj;
        };
        NgxSimpleScrollService.prototype.getElemPos = function (el) {
            if (!el) {
                return null;
            }
            return el.getBoundingClientRect().top;
        };
        NgxSimpleScrollService.prototype.getParent = function (target, selector) {
            if (!selector) {
                return null;
            }
            return target.closest(selector);
        };
        return NgxSimpleScrollService;
    }());
    NgxSimpleScrollService.ɵfac = function NgxSimpleScrollService_Factory(t) { return new (t || NgxSimpleScrollService)(); };
    NgxSimpleScrollService.ɵprov = i0.ɵɵdefineInjectable({ token: NgxSimpleScrollService, factory: NgxSimpleScrollService.ɵfac });
    /*@__PURE__*/ (function () {
        i0.ɵsetClassMetadata(NgxSimpleScrollService, [{
                type: i0.Injectable
            }], null, null);
    })();

    var NgxSimpleScrollDirective = /** @class */ (function () {
        function NgxSimpleScrollDirective(ngxSimpleScrollService) {
            this.ngxSimpleScrollService = ngxSimpleScrollService;
        }
        NgxSimpleScrollDirective.prototype.onClick = function () {
            var _this = this;
            this.async
                ? setTimeout(function () { return _this.ngxSimpleScrollService.scrollTo(_this.config); }, 0)
                : this.ngxSimpleScrollService.scrollTo(this.config);
        };
        NgxSimpleScrollDirective.prototype.ngOnInit = function () {
            this.setConfig();
        };
        NgxSimpleScrollDirective.prototype.ngOnChanges = function () {
            this.setConfig();
        };
        NgxSimpleScrollDirective.prototype.setConfig = function () {
            this.config = {
                targetSelector: this.targetSelector,
                scrollToFocus: this.scrollToFocus,
                scrollToParent: this.scrollToParent,
                parentSelector: this.parentSelector,
                scrollToAnimatedObject: this.scrollToAnimatedObject,
            };
        };
        return NgxSimpleScrollDirective;
    }());
    NgxSimpleScrollDirective.ɵfac = function NgxSimpleScrollDirective_Factory(t) { return new (t || NgxSimpleScrollDirective)(i0.ɵɵdirectiveInject(NgxSimpleScrollService)); };
    NgxSimpleScrollDirective.ɵdir = i0.ɵɵdefineDirective({ type: NgxSimpleScrollDirective, selectors: [["", "ngxSimpleScroll", ""]], hostBindings: function NgxSimpleScrollDirective_HostBindings(rf, ctx) {
            if (rf & 1) {
                i0.ɵɵlistener("click", function NgxSimpleScrollDirective_click_HostBindingHandler() { return ctx.onClick(); });
            }
        }, inputs: { targetSelector: "targetSelector", async: "async", scrollToFocus: "scrollToFocus", scrollToParent: "scrollToParent", parentSelector: "parentSelector", scrollToAnimatedObject: "scrollToAnimatedObject" }, features: [i0.ɵɵNgOnChangesFeature] });
    /*@__PURE__*/ (function () {
        i0.ɵsetClassMetadata(NgxSimpleScrollDirective, [{
                type: i0.Directive,
                args: [{
                        selector: '[ngxSimpleScroll]',
                    }]
            }], function () { return [{ type: NgxSimpleScrollService }]; }, { onClick: [{
                    type: i0.HostListener,
                    args: ['click']
                }], targetSelector: [{
                    type: i0.Input
                }], async: [{
                    type: i0.Input
                }], scrollToFocus: [{
                    type: i0.Input
                }], scrollToParent: [{
                    type: i0.Input
                }], parentSelector: [{
                    type: i0.Input
                }], scrollToAnimatedObject: [{
                    type: i0.Input
                }] });
    })();

    var NgxSimpleScrollModule = /** @class */ (function () {
        function NgxSimpleScrollModule() {
        }
        return NgxSimpleScrollModule;
    }());
    NgxSimpleScrollModule.ɵmod = i0.ɵɵdefineNgModule({ type: NgxSimpleScrollModule });
    NgxSimpleScrollModule.ɵinj = i0.ɵɵdefineInjector({ factory: function NgxSimpleScrollModule_Factory(t) { return new (t || NgxSimpleScrollModule)(); }, providers: [
            NgxSimpleScrollService,
        ] });
    (function () { (typeof ngJitMode === "undefined" || ngJitMode) && i0.ɵɵsetNgModuleScope(NgxSimpleScrollModule, { declarations: [NgxSimpleScrollDirective], exports: [NgxSimpleScrollDirective] }); })();
    /*@__PURE__*/ (function () {
        i0.ɵsetClassMetadata(NgxSimpleScrollModule, [{
                type: i0.NgModule,
                args: [{
                        declarations: [
                            NgxSimpleScrollDirective,
                        ],
                        exports: [
                            NgxSimpleScrollDirective,
                        ],
                        providers: [
                            NgxSimpleScrollService,
                        ],
                    }]
            }], null, null);
    })();

    /*
     * Public API Surface of ngx-simple-scroll
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.NgxSimpleScrollDirective = NgxSimpleScrollDirective;
    exports.NgxSimpleScrollModule = NgxSimpleScrollModule;
    exports.NgxSimpleScrollService = NgxSimpleScrollService;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=lib.umd.js.map
