import { ɵɵdefineInjectable, ɵsetClassMetadata, Injectable, ɵɵdirectiveInject, ɵɵdefineDirective, ɵɵlistener, ɵɵNgOnChangesFeature, Directive, HostListener, Input, ɵɵdefineNgModule, ɵɵdefineInjector, ɵɵsetNgModuleScope, NgModule } from '@angular/core';
import { Subject } from 'rxjs';

class NgxSimpleScrollService {
    constructor() {
        this.config = {
            scrollToFocus: true,
            scrollToParent: false,
            scrollToAnimatedObject: false,
        };
        this.focusParams = { preventScroll: true };
        this.scrollParams = { block: 'center', behavior: 'smooth' };
        this.animationInterval = 50;
    }
    scrollTo(config) {
        const mergedConfig = Object.assign(Object.assign({}, this.config), config);
        const targetSelector = mergedConfig.targetSelector;
        const target = document.querySelector(targetSelector);
        if (!target) {
            return;
        }
        if (mergedConfig.scrollToFocus) {
            this.focus(target, mergedConfig);
        }
        this.scroll(target, mergedConfig);
    }
    focus(target, config) {
        const isInput = target instanceof HTMLInputElement;
        const isTextarea = target instanceof HTMLTextAreaElement;
        if (isInput || isTextarea) {
            target.focus(this.focusParams);
            return;
        }
        if (!config.scrollToParent) {
            return;
        }
        const parent = this.getParent(target, config.parentSelector);
        if (!parent) {
            return;
        }
        const inputElement = parent.querySelector('input, textarea');
        if (!inputElement) {
            return;
        }
        inputElement.focus(this.focusParams);
    }
    scroll(target, config) {
        const el = config.scrollToParent
            ? this.getParent(target, config.parentSelector) || target
            : target;
        el.scrollIntoView(this.scrollParams);
        if (!config.scrollToAnimatedObject) {
            return;
        }
        this.initAnimationDoneSub(el)
            .subscribe(() => el.scrollIntoView(this.scrollParams));
    }
    initAnimationDoneSub(el) {
        const subj = new Subject();
        let position = this.getElemPos(el);
        const interval = setInterval(() => {
            const newPos = this.getElemPos(el);
            if (position !== newPos) {
                position = newPos;
                return;
            }
            clearInterval(interval);
            subj.next();
            subj.complete();
        }, this.animationInterval);
        return subj;
    }
    getElemPos(el) {
        if (!el) {
            return null;
        }
        return el.getBoundingClientRect().top;
    }
    getParent(target, selector) {
        if (!selector) {
            return null;
        }
        return target.closest(selector);
    }
}
NgxSimpleScrollService.ɵfac = function NgxSimpleScrollService_Factory(t) { return new (t || NgxSimpleScrollService)(); };
NgxSimpleScrollService.ɵprov = ɵɵdefineInjectable({ token: NgxSimpleScrollService, factory: NgxSimpleScrollService.ɵfac });
/*@__PURE__*/ (function () { ɵsetClassMetadata(NgxSimpleScrollService, [{
        type: Injectable
    }], null, null); })();

class NgxSimpleScrollDirective {
    constructor(ngxSimpleScrollService) {
        this.ngxSimpleScrollService = ngxSimpleScrollService;
    }
    onClick() {
        this.async
            ? setTimeout(() => this.ngxSimpleScrollService.scrollTo(this.config), 0)
            : this.ngxSimpleScrollService.scrollTo(this.config);
    }
    ngOnInit() {
        this.setConfig();
    }
    ngOnChanges() {
        this.setConfig();
    }
    setConfig() {
        this.config = {
            targetSelector: this.targetSelector,
            scrollToFocus: this.scrollToFocus,
            scrollToParent: this.scrollToParent,
            parentSelector: this.parentSelector,
            scrollToAnimatedObject: this.scrollToAnimatedObject,
        };
    }
}
NgxSimpleScrollDirective.ɵfac = function NgxSimpleScrollDirective_Factory(t) { return new (t || NgxSimpleScrollDirective)(ɵɵdirectiveInject(NgxSimpleScrollService)); };
NgxSimpleScrollDirective.ɵdir = ɵɵdefineDirective({ type: NgxSimpleScrollDirective, selectors: [["", "ngxSimpleScroll", ""]], hostBindings: function NgxSimpleScrollDirective_HostBindings(rf, ctx) { if (rf & 1) {
        ɵɵlistener("click", function NgxSimpleScrollDirective_click_HostBindingHandler() { return ctx.onClick(); });
    } }, inputs: { targetSelector: "targetSelector", async: "async", scrollToFocus: "scrollToFocus", scrollToParent: "scrollToParent", parentSelector: "parentSelector", scrollToAnimatedObject: "scrollToAnimatedObject" }, features: [ɵɵNgOnChangesFeature] });
/*@__PURE__*/ (function () { ɵsetClassMetadata(NgxSimpleScrollDirective, [{
        type: Directive,
        args: [{
                selector: '[ngxSimpleScroll]',
            }]
    }], function () { return [{ type: NgxSimpleScrollService }]; }, { onClick: [{
            type: HostListener,
            args: ['click']
        }], targetSelector: [{
            type: Input
        }], async: [{
            type: Input
        }], scrollToFocus: [{
            type: Input
        }], scrollToParent: [{
            type: Input
        }], parentSelector: [{
            type: Input
        }], scrollToAnimatedObject: [{
            type: Input
        }] }); })();

class NgxSimpleScrollModule {
}
NgxSimpleScrollModule.ɵmod = ɵɵdefineNgModule({ type: NgxSimpleScrollModule });
NgxSimpleScrollModule.ɵinj = ɵɵdefineInjector({ factory: function NgxSimpleScrollModule_Factory(t) { return new (t || NgxSimpleScrollModule)(); }, providers: [
        NgxSimpleScrollService,
    ] });
(function () { (typeof ngJitMode === "undefined" || ngJitMode) && ɵɵsetNgModuleScope(NgxSimpleScrollModule, { declarations: [NgxSimpleScrollDirective], exports: [NgxSimpleScrollDirective] }); })();
/*@__PURE__*/ (function () { ɵsetClassMetadata(NgxSimpleScrollModule, [{
        type: NgModule,
        args: [{
                declarations: [
                    NgxSimpleScrollDirective,
                ],
                exports: [
                    NgxSimpleScrollDirective,
                ],
                providers: [
                    NgxSimpleScrollService,
                ],
            }]
    }], null, null); })();

/*
 * Public API Surface of ngx-simple-scroll
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxSimpleScrollDirective, NgxSimpleScrollModule, NgxSimpleScrollService };
//# sourceMappingURL=lib.js.map
